@@ -55,7 +55,7 @@
 #include "PackageView.h"
 #include "PackageDelegate.h"
 
-#define NUM_COLUMNS 3 // If this is changed change PackageView.cpp value as well
+#define NUM_COLUMNS 6 // If this is changed change PackageView.cpp value as well
 
 bool packageNameLessThan(QApt::Package *p1, QApt::Package *p2)
 {
@@ -110,6 +110,9 @@ PackageWidget::PackageWidget(QWidget *parent)
     m_packageView->setModel(m_proxyModel);
     m_packageView->setItemDelegate(delegate);
     m_packageView->header()->setSectionResizeMode(0, QHeaderView::Stretch);
+    for (int i = 3; i < NUM_COLUMNS; ++i) {
+        m_packageView->header()->setSectionHidden(i, true);
+    }
     topVBox->addWidget(m_packageView);
 
     m_detailsWidget = new DetailsWidget;
@@ -141,8 +144,6 @@ PackageWidget::PackageWidget(QWidget *parent)
             this, SLOT(packageActivated(QModelIndex)));
     connect(m_packageView, SIGNAL(selectionEmpty()), m_detailsWidget, SLOT(hide()));
     connect(m_packageView, SIGNAL(selectionMulti()), m_detailsWidget, SLOT(emitHideButtons()));
-    connect(m_packageView->header(), SIGNAL(sectionClicked(int)),
-            this, SLOT(sectionClicked(int)));
     connect(m_searchEdit, SIGNAL(textChanged(QString)), m_searchTimer, SLOT(start()));
 
     QWidget* topWidget = new QWidget;
@@ -235,6 +236,16 @@ void PackageWidget::setFocusSearchEdit()
     m_searchEdit->selectAll();
 }
 
+QByteArray PackageWidget::saveColumnsState() const
+{
+    return m_packageView->header()->saveState();
+}
+
+bool PackageWidget::restoreColumnsState(const QByteArray& state)
+{
+    return m_packageView->header()->restoreState(state);
+}
+
 void PackageWidget::setBackend(QApt::Backend *backend)
 {
     m_backend = backend;
@@ -242,6 +253,7 @@ void PackageWidget::setBackend(QApt::Backend *backend)
     connect(m_backend, SIGNAL(packageChanged()), m_model, SLOT(externalDataChanged()));
     connect(m_backend, SIGNAL(cacheReloadStarted()), this, SLOT(cacheReloadStarted()));
     connect(m_backend, SIGNAL(cacheReloadFinished()), this, SLOT(cacheReloadFinished()));
+    connect(m_backend, SIGNAL(xapianUpdateFinished()), this, SLOT(startSearch()));
 
     m_detailsWidget->setBackend(backend);
     m_proxyModel->setBackend(m_backend);
@@ -264,7 +276,6 @@ void PackageWidget::cacheReloadStarted()
     m_model->clear();
     m_proxyModel->clear();
     m_proxyModel->reset();
-    m_proxyModel->setSourceModel(0);
     m_busyWidget->start();
 }
 
@@ -273,7 +284,6 @@ void PackageWidget::cacheReloadFinished()
     QApt::PackageList packageList = m_backend->availablePackages();
     QFuture<QList<QApt::Package*> > future = QtConcurrent::run(sortPackages, packageList);
     m_watcher->setFuture(future);
-    m_proxyModel->setSourceModel(m_model);
     m_packageView->header()->setSectionResizeMode(0, QHeaderView::Stretch);
     startSearch();
 }
@@ -394,13 +404,6 @@ void PackageWidget::setSortedPackages()
     QApplication::restoreOverrideCursor();
 }
 
-void PackageWidget::sectionClicked(int section)
-{
-    if (section == 0) {
-        m_proxyModel->setSortByRelevancy(false);
-    }
-}
-
 void PackageWidget::startSearch()
 {
     if (m_proxyModel->sourceModel()) {
